isoduration: Operations with ISO 8601 durations
===============================================

Description
-----------

Operations with ISO 8601 durations

License
-------

Upstream Contact
----------------

https://pypi.org/project/isoduration/

